import { defineStore } from "pinia";
import { http } from "@/serverCom";
import { useEquipmentStore } from "./equipment";
import type { DamageReportViewModel } from "@/viewmodels/admin/unit/damageReport.models";

export const useEquipmentDamageReportStore = defineStore("equipmentDamageReport", {
  state: () => {
    return {
      damageReports: [] as Array<DamageReportViewModel & { tab_pos: number }>,
      totalCount: 0 as number,
      loading: "loading" as "loading" | "fetched" | "failed",
    };
  },
  actions: {
    fetchDamageReportForEquipment(offset = 0, count = 25, search = "", clear = false) {
      const equipmentId = useEquipmentStore().activeEquipment;
      if (clear) this.damageReports = [];
      this.loading = "loading";
      http
        .get(
          `/admin/damagereport/equipment/${equipmentId}?offset=${offset}&count=${count}${search != "" ? "&search=" + search : ""}`
        )
        .then((result) => {
          this.totalCount = result.data.total;
          result.data.damageReports
            .filter((elem: DamageReportViewModel) => this.damageReports.findIndex((m) => m.id == elem.id) == -1)
            .map((elem: DamageReportViewModel, index: number): DamageReportViewModel & { tab_pos: number } => {
              return {
                ...elem,
                tab_pos: index + offset,
              };
            })
            .forEach((elem: DamageReportViewModel & { tab_pos: number }) => {
              this.damageReports.push(elem);
            });
          this.loading = "fetched";
        })
        .catch((err) => {
          this.loading = "failed";
        });
    },
  },
});
