import { defineStore } from "pinia";
import type {
  EquipmentTypeViewModel,
  CreateEquipmentTypeViewModel,
  UpdateEquipmentTypeViewModel,
} from "@/viewmodels/admin/unit/equipment/equipmentType.models";
import { http } from "@/serverCom";
import type { AxiosResponse } from "axios";

export const useEquipmentTypeStore = defineStore("equipmentType", {
  state: () => {
    return {
      equipmentTypes: [] as Array<EquipmentTypeViewModel & { tab_pos: number }>,
      totalCount: 0 as number,
      loading: "loading" as "loading" | "fetched" | "failed",
      activeEquipmentType: null as string | null,
      activeEquipmentTypeObj: null as EquipmentTypeViewModel | null,
      loadingActive: "loading" as "loading" | "fetched" | "failed",
    };
  },
  actions: {
    fetchEquipmentTypes(offset = 0, count = 25, search = "", clear = false) {
      if (clear) this.equipmentTypes = [];
      this.loading = "loading";
      http
        .get(`/admin/equipmentType?offset=${offset}&count=${count}${search != "" ? "&search=" + search : ""}`)
        .then((result) => {
          this.totalCount = result.data.total;
          result.data.equipmentTypes
            .filter((elem: EquipmentTypeViewModel) => this.equipmentTypes.findIndex((m) => m.id == elem.id) == -1)
            .map((elem: EquipmentTypeViewModel, index: number): EquipmentTypeViewModel & { tab_pos: number } => {
              return {
                ...elem,
                tab_pos: index + offset,
              };
            })
            .forEach((elem: EquipmentTypeViewModel & { tab_pos: number }) => {
              this.equipmentTypes.push(elem);
            });
          this.loading = "fetched";
        })
        .catch((err) => {
          this.loading = "failed";
        });
    },
    async getAllEquipmentTypes(): Promise<AxiosResponse<any, any>> {
      return await http.get(`/admin/equipmentType?noLimit=true`).then((res) => {
        return { ...res, data: res.data.equipmentTypes };
      });
    },
    async searchEquipmentTypes(search: string): Promise<AxiosResponse<any, any>> {
      return await http.get(`/admin/equipmentType?search=${search}&noLimit=true`).then((res) => {
        return { ...res, data: res.data.equipmentTypes };
      });
    },
    fetchEquipmentTypeByActiveId() {
      this.loadingActive = "loading";
      http
        .get(`/admin/equipmentType/${this.activeEquipmentType}`)
        .then((res) => {
          this.activeEquipmentTypeObj = res.data;
          this.loadingActive = "fetched";
        })
        .catch((err) => {
          this.loadingActive = "failed";
        });
    },
    fetchEquipmentTypeById(id: string) {
      return http.get(`/admin/equipmentType/${id}`);
    },
    async createEquipmentType(equipmentType: CreateEquipmentTypeViewModel): Promise<AxiosResponse<any, any>> {
      const result = await http.post(`/admin/equipmentType`, {
        type: equipmentType.type,
        description: equipmentType.description,
      });
      this.fetchEquipmentTypes();
      return result;
    },
    async updateActiveEquipmentType(equipmentType: UpdateEquipmentTypeViewModel): Promise<AxiosResponse<any, any>> {
      const result = await http.patch(`/admin/equipmentType/${equipmentType.id}`, {
        type: equipmentType.type,
        description: equipmentType.description,
      });
      this.fetchEquipmentTypes();
      return result;
    },
    async deleteEquipmentType(equipmentType: number): Promise<AxiosResponse<any, any>> {
      const result = await http.delete(`/admin/equipmentType/${equipmentType}`);
      this.fetchEquipmentTypes();
      return result;
    },
  },
});
