import { defineStore } from "pinia";
import type { InspectionPointViewModel } from "@/viewmodels/admin/unit/inspection/inspectionPlan.models";
import { http } from "@/serverCom";
import type { AxiosResponse } from "axios";
import { useInspectionPlanStore } from "./inspectionPlan";

export const useInspectionPointStore = defineStore("inspectionPoint", {
  state: () => {
    return {
      inspectionPoints: [] as Array<InspectionPointViewModel>,
      loading: "loading" as "loading" | "fetched" | "failed",
    };
  },
  actions: {
    fetchInspectionPoints() {
      const inspectionPlanId = useInspectionPlanStore().activeInspectionPlan;
      this.loading = "loading";
      http
        .get(`/admin/inspectionPlan/${inspectionPlanId}/points`)
        .then((result) => {
          this.inspectionPoints = result.data;
          this.loading = "fetched";
        })
        .catch((err) => {
          this.loading = "failed";
        });
    },
    async updateActiveInspectionPoints(
      inspectionPoints: Array<InspectionPointViewModel>
    ): Promise<AxiosResponse<any, any>> {
      const inspectionPlanId = useInspectionPlanStore().activeInspectionPlan;
      const result = await http.patch(`/admin/inspectionPlan/${inspectionPlanId}/points`, inspectionPoints);
      this.fetchInspectionPoints();
      return result;
    },
  },
});
